@@ -40,6 +40,10 @@ class Job(object):
     # Stale results are generally ok, but not no results.
     fetch_on_miss = True
 
+    # --------
+    # MAIN API
+    # --------
+
     def get(self, *raw_args, **raw_kwargs):
         """
         Return the data for this function (using the cache if possible).
@@ -59,7 +63,7 @@ class Job(object):
             # a) fetch the data immediately, blocking execution until
             #    the fetch has finished, or
             # b) trigger an async refresh and return an empty result
-            if self.should_item_by_fetched_synchronously(*args, **kwargs):
+            if self.should_item_be_fetched_synchronously(*args, **kwargs):
                 logger.debug(("Job %s with key '%s' - cache MISS - running "
                               "synchronous refresh"),
                              self.class_path, key)
@@ -96,6 +100,24 @@ class Job(object):
                          key)
         return data
 
+    def invalidate(self, *raw_args, **raw_kwargs):
+        """
+        Mark a cached item invalid and trigger an asynchronous
+        job to refresh the cache
+        """
+        args = self.prepare_args(*raw_args)
+        kwargs = self.prepare_kwargs(**raw_kwargs)
+        key = self.key(*args, **kwargs)
+        item = cache.get(key)
+        if item is not None:
+            expiry, data = item
+            self.cache_set(key, self.timeout(*args, **kwargs), data)
+            self.async_refresh(*args, **kwargs)
+
+    # --------------
+    # HELPER METHODS
+    # --------------
+
     def prepare_args(self, *args):
         return args
 
@@ -111,13 +133,14 @@ class Job(object):
         :data: The data to cache
         """
         cache.set(key, (expiry, data), self.cache_ttl)
+
         # Warning - not all values save correctly to Memcache, some values
         # will fail silently.  It's tricky to test for this behaviour as cached
         # QuerySets aren't "equal" to the original.
-        __, cached_data = cache.get(key)
+        __, cached_data = cache.get(key, (None, None))
         if data is not None and cached_data is None:
             raise RuntimeError(
-                "Unable to save data of type %s to Memcache" % (
+                "Unable to save data of type %s to cache" % (
                     type(data)))
 
     def refresh(self, *args, **kwargs):
@@ -137,12 +160,20 @@ class Job(object):
         # We trigger the task with the class path to import as well as the
         # (a) args and kwargs for instantiating the class
         # (b) args and kwargs for calling the 'refresh' method
-        tasks.refresh_cache.delay(
-            self.class_path,
-            obj_args=self.get_constructor_args(),
-            obj_kwargs=self.get_constructor_kwargs(),
-            call_args=args,
-            call_kwargs=kwargs)
+        try:
+            tasks.refresh_cache.delay(
+                self.class_path,
+                obj_args=self.get_constructor_args(),
+                obj_kwargs=self.get_constructor_kwargs(),
+                call_args=args,
+                call_kwargs=kwargs)
+        except Exception, e:
+            # Handle exceptions from talking to RabbitMQ - eg connection
+            # refused.
+            logger.error("Unable to trigger task asynchronously - failing "
+                         "over to synchronous refresh")
+            logger.exception(e)
+            return self.refresh(*args, **kwargs)
 
     def get_constructor_args(self):
         return ()
@@ -179,7 +210,7 @@ class Job(object):
         """
         return time.time() + self.refresh_timeout
 
-    def should_item_by_fetched_synchronously(self, *args, **kwargs):
+    def should_item_be_fetched_synchronously(self, *args, **kwargs):
         """
         Return whether to refresh an item synchronously
         """
@@ -204,9 +235,10 @@ class Job(object):
                                 hash(tuple(kwargs.keys())),
                                 hash(tuple(kwargs.values())))
         except TypeError:
-            raise RuntimeError("Unable to generate cache key due to unhashable"
-                               "args or kwargs - you need to implement your own"
-                               "key generation method to avoid this problem")
+            raise RuntimeError(
+                "Unable to generate cache key due to unhashable"
+                "args or kwargs - you need to implement your own"
+                "key generation method to avoid this problem")
 
     def fetch(self, *args, **kwargs):
         """
